import React, { useState, useEffect } from 'react';
import { Link, useNavigate, useLocation } from "react-router-dom";
import { useAuth } from "../../contexts/AuthContext";
import { FiSearch, FiMenu, FiX, FiUser } from "react-icons/fi";
import SearchBar from "../ui/SearchBar";
import Logo from "../ui/Logo";

const Header = () => {
  const { user, userProfile, signOut } = useAuth();
  const navigate = useNavigate();
  const location = useLocation();
  const [isScrolled, setIsScrolled] = useState(false);
  const [isMenuOpen, setIsMenuOpen] = useState(false);
  const [isSearchOpen, setIsSearchOpen] = useState(false);

  // Close mobile menu when route changes
  useEffect(() => {
    setIsMenuOpen(false);
    setIsSearchOpen(false);
  }, [location.pathname]);

  // Handle scroll effect for header
  useEffect(() => {
    const handleScroll = () => {
      if (window.scrollY > 10) {
        setIsScrolled(true);
      } else {
        setIsScrolled(false);
      }
    };

    window.addEventListener("scroll", handleScroll);
    return () => window.removeEventListener("scroll", handleScroll);
  }, []);

  const handleLogout = async () => {
    try {
      await signOut();
      navigate("/");
    } catch (error) {
      console.error("Не удалось выйти:", error);
    }
  };

  return (
    <header
      className={`fixed top-0 left-0 right-0 z-50 transition-all duration-300 ${
        isScrolled ? "bg-campfire-dark shadow-lg py-2" : "bg-transparent py-4"
      }`}
    >
      <div className="container-custom">
        <div className="flex items-center justify-between">
          {/* Logo */}
          <Link to="/" className="flex items-center">
            <Logo />
            <span className="ml-2 text-xl font-bold hidden sm:block">
              CampFire Critics
            </span>
          </Link>

          {/* Desktop Navigation */}
          <nav className="hidden md:flex items-center space-x-6">
            <Link
              to="/"
              className="text-campfire-light hover:text-campfire-amber transition-colors"
            >
              Главная
            </Link>
            <Link
              to="/discover/movies"
              className="text-campfire-light hover:text-campfire-amber transition-colors"
            >
              Фильмы
            </Link>
            <Link
              to="/discover/tv"
              className="text-campfire-light hover:text-campfire-amber transition-colors"
            >
              Сериалы
            </Link>
            <Link
              to="/discover/games"
              className="text-campfire-light hover:text-campfire-amber transition-colors"
            >
              Игры
            </Link>
          </nav>

          {/* Search and User Actions */}
          <div className="flex items-center space-x-4">
            <button
              onClick={() => setIsSearchOpen(!isSearchOpen)}
              className="p-2 text-campfire-light hover:text-campfire-amber"
              aria-label="Найти"
            >
              <FiSearch size={20} />
            </button>

            {user ? (
              <div className="relative group">
                <button className="flex items-center space-x-2 p-2 rounded-full bg-campfire-charcoal">
                  {userProfile?.profilePicture ? (
                    <img
                      src={userProfile.profilePicture}
                      alt={userProfile.username}
                      className="w-8 h-8 rounded-full object-cover"
                    />
                  ) : (
                    <FiUser size={20} className="text-campfire-light" />
                  )}
                </button>
                <div className="absolute right-0 mt-2 w-48 py-2 bg-campfire-charcoal rounded-md shadow-xl opacity-0 invisible group-hover:opacity-100 group-hover:visible transition-all duration-300">
                  {userProfile?.role === 'admin' && (
                    <Link
                      to="/admin/media"
                      className="block px-4 py-2 hover:bg-campfire-dark"
                    >
                      Админ панель
                    </Link>
                  )}
                  <Link
                    to={`/profile/${userProfile?.username}`}
                    className="block px-4 py-2 hover:bg-campfire-dark"
                  >
                    Профиль
                  </Link>
                  <button
                    onClick={handleLogout}
                    className="block w-full text-left px-4 py-2 hover:bg-campfire-dark"
                  >
                    Выйти
                  </button>
                </div>
              </div>
            ) : (
              <>
                <Link
                  to="/login"
                  className="text-campfire-light hover:text-campfire-amber transition-colors"
                >
                  Войти
                </Link>
                <Link
                  to="/register"
                  className="btn-primary"
                >
                  Регистрация
                </Link>
              </>
            )}

            {/* Mobile Menu Button */}
            <button
              className="md:hidden p-2 text-campfire-light"
              onClick={() => setIsMenuOpen(!isMenuOpen)}
              aria-label="Меню"
            >
              {isMenuOpen ? <FiX size={24} /> : <FiMenu size={24} />}
            </button>
          </div>
        </div>

        {/* Search Bar (expandable) */}
        <div
          className={`mt-4 transition-all duration-300 overflow-hidden ${
            isSearchOpen ? "max-h-20 opacity-100" : "max-h-0 opacity-0"
          }`}
        >
          <SearchBar onClose={() => setIsSearchOpen(false)} />
        </div>

        {/* Mobile Menu */}
        <div
          className={`md:hidden transition-all duration-300 overflow-hidden ${
            isMenuOpen ? "max-h-96 opacity-100" : "max-h-0 opacity-0"
          }`}
        >
          <nav className="mt-4 flex flex-col space-y-3 pb-4">
            <Link
              to="/"
              className="text-campfire-light hover:text-campfire-amber transition-colors py-2"
            >
              Главная
            </Link>
            <Link
              to="/discover/movies"
              className="text-campfire-light hover:text-campfire-amber transition-colors py-2"
            >
              Фильмы
            </Link>
            <Link
              to="/discover/series"
              className="text-campfire-light hover:text-campfire-amber transition-colors py-2"
            >
              Сериалы
            </Link>
            <Link
              to="/discover/games"
              className="text-campfire-light hover:text-campfire-amber transition-colors py-2"
            >
              Игры
            </Link>
          </nav>
        </div>
      </div>
    </header>
  );
};

export default Header;
