import React, {
  createContext,
  useContext,
  useState,
  useEffect,
} from "react";
import {
  supabase,
  signUp as supabaseSignUp,
  signIn as supabaseSignIn,
  signOut as supabaseSignOut,
  getCurrentUser,
  getUserProfile,
} from "../services/supabase";

const AuthContext = createContext();

export const useAuth = () => {
  const context = useContext(AuthContext);
  if (!context) {
    throw new Error("useAuth must be used within an AuthProvider");
  }
  return context;
};

export const AuthProvider = ({ children }) => {
  const [currentUser, setCurrentUser] = useState(null);
  const [userProfile, setUserProfile] = useState(null);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  // Функция для загрузки профиля пользователя
  const loadUserProfile = async (userId) => {
    try {
      console.log('AuthProvider: Загрузка профиля пользователя:', userId);
      const { data: profile, error: profileError } = await supabase
        .from('users')
        .select('*')
        .eq('id', userId)
        .single();

      if (profileError) {
        if (profileError.code === 'PGRST116') {
          // Если профиль не найден, создаем новый
          console.log('AuthProvider: Профиль не найден, создаем новый');
          const { data: newProfile, error: createError } = await supabase
            .from('users')
            .insert([
              {
                id: userId,
                username: `user_${userId.slice(0, 8)}`,
                role: 'user'
              }
            ])
            .select()
            .single();

          if (createError) throw createError;
          console.log('AuthProvider: Новый профиль создан:', newProfile);
          setUserProfile(newProfile);
        } else {
          throw profileError;
        }
      } else {
        console.log('AuthProvider: Профиль загружен:', profile);
        setUserProfile(profile);
      }
    } catch (error) {
      console.error('AuthProvider: Ошибка загрузки профиля:', error);
      setError(error.message);
    }
  };

  // Проверка сессии при загрузке
  const checkSession = async () => {
    try {
      console.log('AuthProvider: Проверка сессии...');
      const { data: { session }, error: sessionError } = await supabase.auth.getSession();
      console.log('AuthProvider: Результат проверки сессии:', { session, error: sessionError });

      if (sessionError) throw sessionError;

      if (session?.user) {
        console.log('AuthProvider: Пользователь найден в сессии');
        setCurrentUser(session.user);
        await loadUserProfile(session.user.id);
      } else {
        console.log('AuthProvider: Пользователь не найден в сессии');
        setCurrentUser(null);
        setUserProfile(null);
      }
    } catch (error) {
      console.error('AuthProvider: Ошибка проверки сессии:', error);
      setError(error.message);
      setCurrentUser(null);
      setUserProfile(null);
    } finally {
      console.log('AuthProvider: Завершение проверки сессии');
      setLoading(false);
    }
  };

  useEffect(() => {
    console.log('AuthProvider: Инициализация...');
    checkSession();

    const { data: { subscription } } = supabase.auth.onAuthStateChange(async (event, session) => {
      console.log('AuthProvider: Изменение состояния авторизации:', { event, session });
      setLoading(true);

      if (event === 'SIGNED_IN') {
        console.log('AuthProvider: Пользователь вошел в систему');
        setCurrentUser(session.user);
        await loadUserProfile(session.user.id);
      } else if (event === 'SIGNED_OUT') {
        console.log('AuthProvider: Пользователь вышел из системы');
        setCurrentUser(null);
        setUserProfile(null);
      }

      setLoading(false);
    });

    return () => {
      console.log('AuthProvider: Отписка от изменений состояния авторизации');
      subscription.unsubscribe();
    };
  }, []);

  const signIn = async (email, password) => {
    try {
      setLoading(true);
      setError(null);
      const { data, error } = await supabase.auth.signInWithPassword({
        email,
        password
      });
      if (error) throw error;
      return data;
    } catch (error) {
      setError(error.message);
      throw error;
    } finally {
      setLoading(false);
    }
  };

  const signUp = async (email, password) => {
    try {
      setLoading(true);
      setError(null);
      const { data, error } = await supabase.auth.signUp({
        email,
        password
      });
      if (error) throw error;
      return data;
    } catch (error) {
      setError(error.message);
      throw error;
    } finally {
      setLoading(false);
    }
  };

  const signOut = async () => {
    try {
      setLoading(true);
      setError(null);
      const { error } = await supabase.auth.signOut();
      if (error) throw error;
    } catch (error) {
      setError(error.message);
      throw error;
    } finally {
      setLoading(false);
    }
  };

  const value = {
    user: currentUser,
    userProfile,
    loading,
    error,
    signIn,
    signUp,
    signOut
  };

  console.log('AuthProvider: Текущее состояние:', value);

  if (loading || (currentUser && !userProfile)) {
    console.log('AuthProvider: Отображение состояния загрузки');
    return (
      <div className="min-h-screen flex items-center justify-center bg-campfire-dark">
        <div className="text-campfire-amber">Загрузка...</div>
      </div>
    );
  }

  return <AuthContext.Provider value={value}>{children}</AuthContext.Provider>;
};
